@@ -61,8 +61,17 @@ class FFile:
 		"""Aggiungi alla fine del file il contenuto"""
 		if self.__file_exists():
 			self.read_json()
-			list(self.json_[to_key]).append(content)
-			with open(self.nomeFile, "a") as fa:
-				fa.write(json.dump(self.json_))
+			lista = list()
+			if to_key in self.json_:
+				lista.append(self.json_[to_key])
+			else:
+				lista = []
+			lista.append(content)
+			self.json_[to_key] = lista
+			with open(self.nomeFile, "w") as fa:
+				fa.write(json.dumps(self.json_))
 		else:
-			self.create_file(json.dump(content))
\ No newline at end of file
+			self.create_file(json.dumps({to_key: content}))
+
+if __name__ == "__main__":
+	test = FFile("prova.json")
\ No newline at end of file
